@@ -1,8 +1,8 @@
 #include "ghash.h"
 
-void* ghash_get(struct ghash* d, const void* key, unsigned long hash,
-		adt_cmp_fn* keycmp)
+void** ghash_find(struct ghash* d, const void* key)
 {
+  const adt_hash_t hash = d->hashfn(key);
   const unsigned size = d->size;
   unsigned start;
   unsigned i;
@@ -18,10 +18,18 @@ void* ghash_get(struct ghash* d, const void* key, unsigned long hash,
     void* entry = *p;
     if (entry == 0) return 0;
     if (ghash_entry_hash(entry) == hash &&
-	keycmp(key, ghash_entry_keyptr(entry)) == 0)
-      return entry;
+	d->keycmp(key, ghash_entry_keyptr(entry)) == 0)
+      return p;
     ++p;
     if (++i >= size) i = 0, p = d->table;
   } while (i != start);
   return 0;
 }
+
+void* ghash_get(struct ghash* d, const void* key)
+{
+  void** entry;
+  if ((entry = ghash_find(d, key)) == 0)
+    return 0;
+  return *entry;
+}
