@@ -1,5 +1,5 @@
 #include <unistd.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Copy all the data from an \c ibuf to an \c obuf. */
 int obuf_copyfromfd(int in, obuf* out)
